class Properties:

    def blank_instance(self, class_):

        class Empty:
            pass

        output = Empty()
        output.__class__ = class_
        return output

    def from_(self, object_):
        if hasattr(object_, 'buffer'):
            return object_.buffer
        return vars(object_)

    def set(self, object_, properties):
        if properties != (None,) and properties is not None:
            for key, value in properties.items():
                setattr(object_, key, value)

    def object_from(self, class_, properties, super_class=None):
        object_ = self.blank_instance(class_)
        self.check_class(object_, super_class)
        self.set(object_, properties)
        return object_

    def check_class(self, object_, super_class):
        error_message = 'Error - #{object.class} should be an instance of #{super_class}'
        if not issubclass(type(object_), super_class):
            raise Exception(error_message)

    def valid_object(self, object_, super_class):
        pass

    def from_comple_type(self, object_):
        pass

    def set_complex_type(self, object_, props):
        pass

    def is_special_case(self, object_):
        pass



"""import datetime, os
LOCAL_TIMEZONE = datetime.datetime.now(datetime.timezone.utc).astimezone().tzinfo
print(LOCAL_TIMEZONE)
# print(os.environ[])



class Test:
    class_var = 1

    def __init__(self):
        pass

    def get_value(self):
        return self.class_var

    def set_value(self, value):
        self.__class__.class_var = value



test_instance1 = Test()
print(test_instance1.class_var)
test_instance1.set_value(value=2)
Test().set_value(value=2)
# Test.class_var = 2
test_instance2 = Test()
print(test_instance2.class_var)
print(test_instance1.class_var)

now = datetime.datetime.now()
print(now)
now = now.replace(day=23)
print(now)

print(now.month)"""


class WithDuration:
    def __test(self):
        print('__init_now_then')


class WithTimestamp(WithDuration):
    pass


class Wait(WithTimestamp):
    pass


# Wait().__test()

import time

print(time.time())



import json


class Serializer:

    def __init__(self):
        pass

    def encode(self, data):
        return '{\"o\":\"@zenaton#0\",\"s\":[{\"a\":' + json.dumps(data, sort_keys=True) + '}]}'

    def decode(self, json_string):
        return json.loads(json_string)['s'][0]['a']

    def __is_basic_type(self, data):
        pass

    def __encode_value(self, value):
        pass

    def __encode_to_store(self, object_):
        pass

    def __store_and_encode(self, object_):
        pass

    def __store_id(self, id):
        pass

    def __encode_object_by_type(self, object_):
        pass

    def __encode_object(self, object_):
        pass

    def __encode_list(self, list_):
        pass

    def __encode_dict(self, dict_):
        pass

    def __encode_legacy_dict(self, dict_):
        pass

    def __is_store_if(self, string_):
        pass

    def __decode_element(self, value):
        pass

    def __decode_enumerable(self, enumerable):
        pass

    def __decode_legacy_list(self, list_):
        pass

    def __decode_legacy_dict(self, dict_):
        pass

    def __decode_list(self, list_):
        pass

    def __decode_dict(self, dict_):
        pass

    def __decode_from_store(self, id, encoded):
        pass

    def __decoded_object_by_type(self, id, encoded):
        pass

    def __decoded_object(self, id, encoded_object):
        pass

    def __transsform_values(self, dict_):
        pass
